@@ -4,7 +4,7 @@ use strict;
 use Vimana::Index;
 
 use vars qw($INDEX);
-our $VERSION = 2010.06109 ;
+our $VERSION = 2010.06501 ;
 
 sub index {
     return $INDEX if $INDEX;
@@ -31,18 +31,11 @@ Debian linux, for you to search , download , install , upgrade scripts from
 L<http://www.vim.org> (vimonline site).
 
 Vimana can install a vim script package to your vim runtime path automatically
-by inspecting the content of archive file or vim script. for example , if an
+by inspecting the content of archive file or vim script. For example , if an
 archive file contains 'syntax','plugin','indent' directory , then these files
-should be installed to F<~/.vim/> directory.   if it's a vim color scheme ,
-then it should be put into F<~/.vim/colors/> and prompt for setting the
-installed colorscheme as default.
-
-We plan to provide port files via git repository, vimrc customization and
-internationalization in future.
-
-( In some modern Indian languages, vimāna or vimān means "aircraft". )
-
-NOTE: Vimana only provides search,info,install commmands currently.
+should be installed to F<~/.vim/> directory (default vim runtime directory).   
+if it's a vim color scheme , then it should be put into F<~/.vim/colors/>,
+or Vimana will inspect the script type tag in script file.
 
 * Getting started from L<Vimana::Manual>.
 
@@ -64,6 +57,13 @@ to install package:
 
     $ vimana i autocomplpop.vim
 
+    # with verbose message
+    $ vimana i -v the-nerd-tree
+
+to remove a package:
+
+    $ vimana remove the-nerd-tree
+
 =head1 FUNCTIONS
 
 =head1 AUTHOR
